$(function() {

	var XYZ2CIELab = function(XYZ) {
		var CIELab = {};
		// Observer = 2°, Illuminant = D65
		var X = XYZ.x / 95.047;
		var Y = XYZ.y / 100.000;
		var Z = XYZ.z / 108.883;

		if (X > 0.008856) {
			X = Math.pow(X, 0.333333333);
		}
		else {
			X = 7.787 * X + 0.137931034;
		}

		if (Y > 0.008856) {
			Y = Math.pow(Y, 0.333333333);
		}
		else {
			Y = 7.787 * Y + 0.137931034;
		}

		if (Z > 0.008856) {
			Z = Math.pow(Z, 0.333333333);
		}
		else {
			Z = 7.787 * Z + 0.137931034;
		}

		CIELab.l = (116 * Y) - 16;
		CIELab.a = 500 * (X - Y);
		CIELab.b = 200 * (Y - Z);

		return CIELab;
	};

	var rgb2XYZ = function(rgb) {
		var XYZ = {};

		var r = (rgb.r / 255);
		var g = (rgb.g / 255);
		var b = (rgb.b / 255);

		if (r > 0.04045) {
			r = Math.pow(((r + 0.055) / 1.055), 2.4);
		}
		else {
			r = r / 12.92;
		}

		if (g > 0.04045) {
			g = Math.pow(((g + 0.055) / 1.055), 2.4);
		}
		else {
			g = g / 12.92;
		}

		if (b > 0.04045) {
			b = Math.pow(((b + 0.055) / 1.055), 2.4);
		}
		else {
			b = b / 12.92;
		}

		r = r * 100;
		g = g * 100;
		b = b * 100;

		// Observer = 2°, Illuminant = D65
		XYZ.x = r * 0.4124 + g * 0.3576 + b * 0.1805;
		XYZ.y = r * 0.2126 + g * 0.7152 + b * 0.0722;
		XYZ.z = r * 0.0193 + g * 0.1192 + b * 0.9505;

		return XYZ;
	};

	function cielch (CIELab) {
		CIELab = XYZ2CIELab(rgb2XYZ(CIELab));
		var CIELCH = {};

		CIELCH.l = CIELab.l;
		CIELCH.c = Math.sqrt(Math.pow(CIELab.a, 2) + Math.pow(CIELab.b, 2));

		CIELCH.h = Math.atan2(CIELab.b, CIELab.a);  //Quadrant by signs

		if (CIELCH.h > 0) {
			CIELCH.h = (CIELCH.h / Math.PI) * 180;
		}
		else {
			CIELCH.h = 360 - (Math.abs(CIELCH.h) / Math.PI) * 180;
		}

		return CIELCH;
	};

	$('.color').each(function() {
		var el = this;
		var rgb_arr = $(this).css("backgroundColor").match(/\d+/g);
		var rgb ={};
		rgb.r = rgb_arr[0];
		rgb.g = rgb_arr[1];
		rgb.b = rgb_arr[2];
		var c = cielch(rgb);
		if (c.l < 60) {
			$(el).css("color", "white");
		}
		else {
			$(el).css("color", "black");
		}
	});



	var cssShowColor = function(el,rgb,hex) {
		var c = cielch(rgb);
		// 	$(el).css("backgroundColor","#"+hex);
		$(el).closest(".input-group").find(".color").css("backgroundColor","#"+hex);

		if (c.l < 60) {
			$(el).closest(".input-group").find(".color").css("color","white");
		}
		else {
			$(el).closest(".input-group").find(".color").css("color","black");
		}
	};

	$('.colorcode').colpick({
		colorScheme:'dark',
		onChange:function(hsb,hex,rgb,el,bySetColor) {
			cssShowColor(el,rgb,hex);
			$(el).val('#'+hex);
			//       $(el).closest(".input-group").find(".color").val("#" + hex);
		},

		onSubmit:function(hsb,hex,rgb,el,bySetColor) {
			cssShowColor(el,rgb,hex);
			//     $(el).closest(".input-group").find("input").val("#" + hex);

			$(el).val('#'+hex);
			$(el).colpickHide();
		}

	});


	$(".input-group-addon.color").on("click", function() {
		$(this).closest(".input-group").find(".colorcode").trigger("click");
	});
});